@@ -54,7 +54,8 @@ def test_vivado_minimal(params, tmpdir):
 
     if synth_tool == "yosys":
         config_file_list.append(name+'.mk')
-        config_file_list.append('yosys.tcl')
+        config_file_list.append('edalize_yosys_procs.tcl')
+        config_file_list.append('edalize_yosys_template.tcl')
     else:
         config_file_list.append(name+'_synth.tcl')
 
